@@ -29,7 +29,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2009  Craig Barratt
+#   Copyright (C) 2001-2013  Craig Barratt
 #
 #   See http://backuppc.sourceforge.net.
 #
@@ -976,7 +976,7 @@ $Conf{SmbClientPath} = '';
 # redirection and pipes; put that in a script if you need it.
 #
 $Conf{SmbClientFullCmd} = '$smbClientPath \\\\$host\\$shareName'
-	    . ' $I_option -U $userName -E -N -d 1'
+	    . ' $I_option -U $userName -E -d 1'
             . ' -c tarmode\\ full -Tc$X_option - $fileList';
 
 #
@@ -990,7 +990,7 @@ $Conf{SmbClientFullCmd} = '$smbClientPath \\\\$host\\$shareName'
 # redirection and pipes; put that in a script if you need it.
 #
 $Conf{SmbClientIncrCmd} = '$smbClientPath \\\\$host\\$shareName'
-	    . ' $I_option -U $userName -E -N -d 1'
+	    . ' $I_option -U $userName -E -d 1'
 	    . ' -c tarmode\\ full -TcN$X_option $timeStampFile - $fileList';
 
 #
@@ -1008,7 +1008,7 @@ $Conf{SmbClientIncrCmd} = '$smbClientPath \\\\$host\\$shareName'
 # redirection and pipes; put that in a script if you need it.
 #
 $Conf{SmbClientRestoreCmd} = '$smbClientPath \\\\$host\\$shareName'
-            . ' $I_option -U $userName -E -N -d 1'
+            . ' $I_option -U $userName -E -d 1'
             . ' -c tarmode\\ full -Tx -';
 
 ###########################################################################
@@ -1047,11 +1047,14 @@ $Conf{SmbClientRestoreCmd} = '$smbClientPath \\\\$host\\$shareName'
 $Conf{TarShareName} = '/';
 
 #
-# Full command to run tar on the client.  GNU tar is required.  You will
+# Command to run tar on the client.  GNU tar is required.  You will
 # need to fill in the correct paths for ssh2 on the local host (server)
 # and GNU tar on the client.  Security caution: normal users should not
 # allowed to write to these executable files or directories.
 #
+# $Conf{TarClientCmd} is appended with with either $Conf{TarFullArgs} or
+# $Conf{TarIncrArgs} to create the final command that is run.
+#
 # See the documentation for more information about setting up ssh2 keys.
 #
 # If you plan to use NFS then tar just runs locally and ssh2 is not needed.
