@@ -19,7 +19,7 @@
 #   Craig Barratt <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2009  Craig Barratt
+#   Copyright (C) 2001-2013  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
 #
 #========================================================================
 #
-# Version 3.2.0, released 31 Jul 2010.
+# Version 3.3.0, released 14 Apr 2013.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -72,7 +72,7 @@ BackupPC cannot load the package $pkg, which is included in the
 BackupPC distribution.  This probably means you did not cd to the
 unpacked BackupPC distribution before running configure.pl, eg:
 
-    cd BackupPC-3.2.0
+    cd BackupPC-3.3.0
     ./configure.pl
 
 Please try again.
@@ -636,9 +636,12 @@ foreach my $lib ( qw(
         lib/BackupPC/Lang/es.pm
         lib/BackupPC/Lang/fr.pm
         lib/BackupPC/Lang/it.pm
+        lib/BackupPC/Lang/ja.pm
         lib/BackupPC/Lang/nl.pm
         lib/BackupPC/Lang/pl.pm
         lib/BackupPC/Lang/pt_br.pm
+        lib/BackupPC/Lang/ru.pm
+        lib/BackupPC/Lang/uk.pm
         lib/BackupPC/Lang/zh_CN.pm
         lib/BackupPC/Storage/Text.pm
         lib/BackupPC/Xfer.pm
@@ -667,7 +670,7 @@ if ( $Conf{CgiImageDir} ne "" ) {
     #
     # Install new CSS file, making a backup copy if necessary
     #
-    my $cssBackup = "$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css.pre-3.2.0";
+    my $cssBackup = "$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css.pre-3.3.0";
     if ( -f "$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css" && !-f $cssBackup ) {
 	rename("$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css", $cssBackup);
     }
@@ -885,7 +888,7 @@ foreach my $param ( keys(%{$opts{"config-override"}}) ) {
 #
 # Now backup and write the config file
 #
-my $confCopy = "$dest.pre-3.2.0";
+my $confCopy = "$dest.pre-3.3.0";
 if ( -f $dest && !-f $confCopy ) {
     #
     # Make copy of config file, preserving ownership and modes
@@ -1378,7 +1381,7 @@ Craig Barratt <cbarratt@users.sourceforge.net>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001-2009  Craig Barratt.
+Copyright (C) 2001-2010  Craig Barratt.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
