@@ -12,7 +12,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2009  Craig Barratt
+#   Copyright (C) 2001-2013  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #
 #========================================================================
 #
-# Version 3.2.0, released 31 Jul 2010.
+# Version 3.3.0, released 14 Apr 2013.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -297,10 +297,15 @@ sub writeData
                     = $a->{files}{$file}{size} % (4096 * 1024 * 1024);
         $a->{files}{$file}{sizeDiv4GB}
                     = int($a->{files}{$file}{size} / (4096 * 1024 * 1024));
-	$data .= pack("w a* w$nFldsW N$nFldsN", length($file), $file,
-			       @{$a->{files}{$file}}{@FldsUnixW},
-			       @{$a->{files}{$file}}{@FldsUnixN},
-                    );
+        eval {
+            $data .= pack("w a* w$nFldsW N$nFldsN", length($file), $file,
+                                   @{$a->{files}{$file}}{@FldsUnixW},
+                                   @{$a->{files}{$file}}{@FldsUnixN},
+                        );
+        };
+        if ( $@ ) {
+            $a->{_errStr} = "Can't pack attr for $file: " . Dumper($a->{files}{$file});
+        }
     }
     return $data;
 }
