@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2004-2009  Craig Barratt
+#   Copyright (C) 2004-2013  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 3.2.0, released 31 Jul 2010.
+# Version 3.3.0, released 14 Apr 2013.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -351,7 +351,7 @@ use vars qw(%ConfigMeta);
     CgiURL	 	=> "string",
     Language	 	=> {
 	    type   => "select",
-	    values => [qw(cz de en es fr it nl pl pt_br zh_CN)],
+	    values => [qw(cz de en es fr it ja nl pl pt_br ru uk zh_CN)],
     },
     CgiUserHomePageCheck => "string",
     CgiUserUrlCreate    => "string",
