@@ -1,4 +1,4 @@
-#!/bin/perl
+#!/usr/bin/perl
 #
 # by Ralph Passgang <ralph@debianbase.de> (13.11.2006 for V3.0.0)
 # by Ralph Passgang <ralph@debianbase.de> (30.06.2006 for V3.0.0)
@@ -49,12 +49,16 @@ $Lang{Admin_Options_Page} = <<EOF;
 </ul>
 -->
 EOF
-$Lang{Unable_to_connect_to_BackupPC_server} = "Kann keine Verbindung zu dem BackupPC Server herstellen!",
-            "Dieses CGI Script (\$MyURL) kann keine Verbindung zu dem BackupPC"
-          . " Server auf \$Conf{ServerHost} Port \$Conf{ServerPort} herstellen. Der Fehler"
-          . " war: \$err.",
-            "Mglicherweise ist der BackupPC Server Prozess nicht gestartet oder es besteht ein"
-          . " Konfigurationsfehler. Bitte teilen Sie diese Fehlermeldung dem Systemadministrator mit.";
+
+$Lang{Unable_to_connect_to_BackupPC_server} = "Kann keine Verbindung zu dem BackupPC Server herstellen!";
+$Lang{Unable_to_connect_to_BackupPC_server_error_message} = <<EOF;
+Dieses CGI Script (\$MyURL) kann keine Verbindung zu dem BackupPC Server
+auf \$Conf{ServerHost} Port \$Conf{ServerPort} herstellen.<br>
+Der Fehler war: \$err.<br>
+Mglicherweise ist der BackupPC Server Prozess nicht gestartet oder es besteht ein
+Konfigurationsfehler. Bitte teilen Sie diese Fehlermeldung dem Systemadministrator mit.
+EOF
+
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
 <form action="\$MyURL" method="get">
@@ -141,8 +145,8 @@ $Lang{BackupPC_Summary}=<<EOF;
 <li>Dieser Status wurde am \$now generiert.
 <li>Das Pool Filesystem (Backup-Speicherplatz) ist zu \$Info{DUlastValue}%
     (\$DUlastTime) voll, das Maximum heute ist \$Info{DUDailyMax}% (\$DUmaxTime)
-    und das Maximum gestern war \$Info{DUDailyMaxPrev}%. (Hinweis: Sollten ca. 70% ?berschritten werden, so
-    ist evtl. bald eine Erweiterung des Backupspeichers erforderlich. Ist weitere Planung n?tig?)
+    und das Maximum gestern war \$Info{DUDailyMaxPrev}%. (Hinweis: Sollten ca. 70% berschritten werden, so
+    ist evtl. bald eine Erweiterung des Backupspeichers erforderlich. Ist weitere Planung ntig?)
 </ul>
 </p>
 
@@ -167,6 +171,7 @@ Es gibt \$hostCntGood Computer die erfolgreich gesichert wurden, mit insgesamt:
     <td align="center"> Alter (Tage) </td>
     <td align="center"> Letzes Backup (Tage) </td>
     <td align="center"> Status </td>
+    <td align="center"> #Xfer Fehler </td>
     <td align="center"> Letzte Aktion </td></tr>
 \$strGood
 </table>
@@ -186,6 +191,7 @@ Es gibt \$hostCntNone Computer ohne Backups !!!
     <td align="center"> Alter (Tage) </td>
     <td align="center"> Letztes Backup (Tage) </td>
     <td align="center"> Status </td>
+    <td align="center"> #Xfer Fehler </td>
     <td align="center"> Letzter Versuch </td></tr>
 \$strNone
 </table>
@@ -536,8 +542,15 @@ evtl. die Dateien/Verzeichnisse erneut und lassen sehr groe und unntige Dateien
  \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (andernfalls enthlt die Archiv Datei vollstndige Pfade).
 <br>
-Kompression (0=aus, 1=schnelle,...,9=hchste)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Kompression (0=aus, 1=schnelle,...,9=hchste)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Zip Datei downloaden" name="ignore">
 </form>
@@ -829,7 +842,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Inhalt von \${EscHTML(\$dirDisplay)}")}
+\${h2("Inhalt von \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -884,7 +897,7 @@ Diese Ansicht zeigt alle unterschiedlichen Versionen der Dateien in den Datensic
 <li> Dateien mit der gleichen Version knnen unterschiedliche Attribute haben. Whlen Sie die Datensicherungsnummer um die Attribute anzuzeigen.
 </ul>
 
-\${h2("Historie von \${EscHTML(\$dirDisplay)}")}
+\${h2("Historie von \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -974,7 +987,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "Nur berechtigte Benutzer knnen Backups starten und stoppen fr"
 		. " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "ungltige Nummer \$num";
+$Lang{Invalid_number__num} = "ungltige Nummer \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "kann Datei nicht ffnen \$file: Konfigurationsproblem?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Nur berechtigte Benutzer knnen Log oder Config Dateien einsehen.";
 $Lang{Only_privileged_users_can_view_log_files} = "Nur berechtigte Benutzer knnen LOG Dateien einsehen.";
@@ -1203,7 +1216,7 @@ $Lang{No} = "nein";
 $Lang{Yes} = "ja";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">Das Verzeichnis \${EscHTML(\$dirDisplay)} ist leer.
+<tr><td bgcolor="#ffffff">Das Verzeichnis \$dirDisplay ist leer.
 </td></tr>
 EOF
 
@@ -1387,11 +1400,11 @@ $Lang{CfgEdit_Title_User_URLs} = "Benutzer URLs";
 $Lang{CfgEdit_Title_User_Config_Editing} = "Benutzerkonfiguration ndern";
 $Lang{CfgEdit_Title_Xfer} = "Xfer";
 $Lang{CfgEdit_Title_Xfer_Settings} = "Xfer Einstellungen";
+$Lang{CfgEdit_Title_Ftp_Settings} = "FTP Einstellungen";
 $Lang{CfgEdit_Title_Smb_Settings} = "Smb Einstellungen";
 $Lang{CfgEdit_Title_Tar_Settings} = "Tar Einstellungen";
 $Lang{CfgEdit_Title_Rsync_Settings} = "Rsync Einstellungen";
 $Lang{CfgEdit_Title_Rsyncd_Settings} = "Rsyncd Einstellungen";
-$Lang{CfgEdit_Title_BackupPCd_Settings} = "BackupPCd Einstellungen";
 $Lang{CfgEdit_Title_Archive_Settings} = "Archive Einstellungen";
 $Lang{CfgEdit_Title_Include_Exclude} = "Include/Exclude";
 $Lang{CfgEdit_Title_Smb_Paths_Commands} = "Smb Pfade/Kommandos";
@@ -1406,7 +1419,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Blackouts";
 $Lang{CfgEdit_Title_Other} = "Andere";
 $Lang{CfgEdit_Title_Backup_Settings} = "Backup Einstellungen";
 $Lang{CfgEdit_Title_Client_Lookup} = "Auflsen des Klienten";
-$Lang{CfgEdit_Title_Other} = "Andere Werte";
 $Lang{CfgEdit_Title_User_Commands} = "Benutzer Kommandos";
 $Lang{CfgEdit_Title_Hosts} = "Hosts";
 
