@@ -531,8 +531,15 @@ local para almacenarlo.
 a \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (en caso contrario el archivo contendr las rutas completas).
 <br>
-Compresin (0=desactivada, 1=rpida,...,9=mxima)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Compresin (0=desactivada, 1=rpida,...,9=mxima)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Download Zip File" name="ignore">
 </form>
@@ -827,7 +834,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Contenido de \${EscHTML(\$dirDisplay)}")}
+\${h2("Contenido de \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -887,7 +894,7 @@ las copias de seguridad:
      Seleccione el nmero de copia de seguridad para ver los atributos del archivo.
 </ul>
 
-\${h2("History of \${EscHTML(\$dirDisplay)}")}
+\${h2("History of \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -977,7 +984,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "Slo los usuarios autorizados pueden comenzar a detener las copias"
 		. " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "Nmero no vlido \$num";
+$Lang{Invalid_number__num} = "Nmero no vlido \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "No puedo abrir \$file: problema de configuracin?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Slo los usuarios autorizados pueden ver registros o archivos de configuracin.";
 $Lang{Only_privileged_users_can_view_log_files} = "Slo los usuarios autorizados pueden ver archivos de registro.";
@@ -1207,7 +1214,7 @@ $Lang{No} = "no";
 $Lang{Yes} = "si";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">El directorio \${EscHTML(\$dirDisplay)} est vacio
+<tr><td bgcolor="#ffffff">El directorio \$dirDisplay est vacio
 </td></tr>
 EOF
 
@@ -1408,7 +1415,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Blackouts";
 $Lang{CfgEdit_Title_Other} = "Other";
 $Lang{CfgEdit_Title_Backup_Settings} = "Backup Settings";
 $Lang{CfgEdit_Title_Client_Lookup} = "Client Lookup";
-$Lang{CfgEdit_Title_Other} = "Other";
 $Lang{CfgEdit_Title_User_Commands} = "User Commands";
 $Lang{CfgEdit_Title_Hosts} = "Hosts";
 
