@@ -1,4 +1,4 @@
-#!/bin/perl
+#!/usr/bin/perl
 
 #my %Lang;
 #use strict;
@@ -40,18 +40,22 @@ $Lang{Admin_Options_Page} = <<EOF;
 </ul>
 -->
 EOF
-$Lang{Unable_to_connect_to_BackupPC_server} = "Impossible de se connecter au serveur BackupPC",
-            "Ce script CGI (\$MyURL) est incapable de se connecter au serveur BackupPC"
-          . " sur \$Conf{ServerHost} au port \$Conf{ServerPort}. L'erreur"
-          . " est: \$err."
-          . " Il est possible que le serveur BackupPC ne fonctionne pas actuellement ou qu'il"
-          . " y ait une erreur de configuration. Veuillez contacter votre administrateur systme.";
+
+$Lang{Unable_to_connect_to_BackupPC_server} = "Impossible de se connecter au serveur BackupPC";
+$Lang{Unable_to_connect_to_BackupPC_server_error_message} = <<EOF;
+Ce script CGI (\$MyURL) est incapable de se connecter au serveur BackupPC
+sur \$Conf{ServerHost} au port \$Conf{ServerPort}.<br>
+L'erreur est: \$err.<br>
+Il est possible que le serveur BackupPC ne fonctionne pas actuellement ou qu'il
+y ait une erreur de configuration. Veuillez contacter votre administrateur systme.
+EOF
+
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
 <form action="\$MyURL" method="get">
 Le serveur BackupPC sur <tt>\$Conf{ServerHost}</tt>, port <tt>\$Conf{ServerPort}</tt>
 n'est pas en fonction (vous l'avez peut-tre arrt, ou vous ne l'avez pas encore dmarr).<br>
-Voulez-vous le dmarrer?
+Voulez-vous le dmarrer ?
 <input type="hidden" name="action" value="startServer">
 <input type="submit" value="Dmarrer le serveur" name="ignore">
 </form>
@@ -67,7 +71,7 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
 <ul>
 <li> Le PID du serveur est \$Info{pid}, sur l\'hte \$Conf{ServerHost},
      version \$Info{Version}, dmarr le \$serverStartTime.
-<li> Ce rapport  t gnr le \$now.
+<li> Ce rapport a t gnr le \$now.
 <li> La configuration a t charge pour la dernire fois  \$configLoadTime.
 <li> La prochaine file d\'attente sera remplie  \$nextWakeupTime.
 <li> Autres infos:
@@ -78,7 +82,7 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
         \$poolInfo
         <li>L\'espace de stockage a t rcemment rempli  \$Info{DUlastValue}%
             (\$DUlastTime), le maximum aujourd\'hui a t de \$Info{DUDailyMax}% (\$DUmaxTime)
-            et hier le maximum tait \$Info{DUDailyMaxPrev}%.
+            et hier le maximum tait de \$Info{DUDailyMaxPrev}%.
     </ul>
 </ul>
 EOF
@@ -125,7 +129,12 @@ $Lang{BackupPC_Summary}=<<EOF;
 
 \${h1(qq{$Lang{BackupPC__Server_Summary}})}
 <p>
-Ce statut a t gnr le \$now.
+<ul>
+<li>Ce statut a t gnr le \$now.
+<li>L\'espace de stockage a t rcemment rempli  \$Info{DUlastValue}%
+    (\$DUlastTime), le maximum aujourd\'hui a t de \$Info{DUDailyMax}% (\$DUmaxTime)
+    et hier le maximum tait de \$Info{DUDailyMaxPrev}%.
+</ul>
 </p>
 
 \${h2("Htes avec de bonnes sauvegardes")}
@@ -138,7 +147,7 @@ Il y a \$hostCntGood htes ayant t sauvegards, pour un total de :
      (prcdant la mise en commun et la compression).
 </ul>
 </p>
-<table class="tableStnd" border cellpadding="3" cellspacing="1">
+<table class="sortable" id="host_summary_backups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Hte </td>
     <td align="center"> Utilisateur </td>
     <td align="center"> Nb compltes </td>
@@ -149,6 +158,7 @@ Il y a \$hostCntGood htes ayant t sauvegards, pour un total de :
     <td align="center"> Incrmentielles ge (jours) </td>
     <td align="center"> Dernire sauvegarde (jours) </td>
     <td align="center"> tat actuel </td>
+    <td align="center"> Nb erreurs transfert </td>
     <td align="center"> Dernire tentative </td></tr>
 \$strGood
 </table>
@@ -157,7 +167,7 @@ Il y a \$hostCntGood htes ayant t sauvegards, pour un total de :
 <p>
 Il y a \$hostCntNone htes sans sauvegardes.
 <p>
-<table class="tableStnd" border cellpadding="3" cellspacing="1">
+<table class="sortable" id="host_summary_nobackups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Hte </td>
     <td align="center"> Utilisateur </td>
     <td align="center"> Nb compltes </td>
@@ -168,6 +178,7 @@ Il y a \$hostCntNone htes sans sauvegardes.
     <td align="center"> Incrmentielles ge (jours) </td>
     <td align="center"> Dernire sauvegarde (jours) </td>
     <td align="center"> tat actuel </td>
+    <td align="center"> Nb erreurs transfert </td>
     <td align="center"> Dernire tentative </td></tr>
 \$strNone
 </table>
@@ -298,7 +309,7 @@ EOF
 $Lang{BackupPC__Start_Backup_Confirm_on__host} = "BackupPC: Confirmation du dmarrage de la sauvegarde de \$host";
 # --------------------------------
 $Lang{Are_you_sure_start} = <<EOF;
-\${h1("tes vous certain ?")}
+\${h1("tes-vous certain ?")}
 <p>
 Vous allez bientt dmarrer une sauvegarde \$type depuis \$host.
 
@@ -319,7 +330,7 @@ $Lang{BackupPC__Stop_Backup_Confirm_on__host} = "BackupPC: Confirmer l\'arrt de
 # --------------------------------
 $Lang{Are_you_sure_stop} = <<EOF;
 
-\${h1("tes vous certain ?")}
+\${h1("tes-vous certain ?")}
 
 <p>
 Vous tes sur le point d\'arrter/supprimer de la file les sauvegardes de \$host;
@@ -451,7 +462,7 @@ EOF
 
 $Lang{Restore_Options_for__host_Option1} = <<EOF;
 Vous pouvez dmarrer une restauration de ces fichiers 
-directement sur \$host.
+directement sur <b>\$directHost</b>.
 </p><p>
 <b>Attention:</b>
 tous les fichiers correspondant  ceux que vous avez slectionns vont tre crass !
@@ -517,8 +528,15 @@ et transfrer cette archive, et vous aurez besoin d\'assez d\'espace disque pour
 \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (Autrement l\'archive contiendra les chemins complets).
 <br>
-Compression (0=dsactive, 1=rapide,...,9=meilleure)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Compression (0=dsactive, 1=rapide,...,9=meilleure)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Tlcharger le fichier Zip" name="ignore">
 </form>
@@ -571,7 +589,7 @@ EOF
 $Lang{Restore_Confirm_on__host} = "BackupPC: Confirmation de restauration sur \$host";
 
 $Lang{Are_you_sure} = <<EOF;
-\${h1("tes-vous sur ?")}
+\${h1("tes-vous sr ?")}
 <p>
 Vous tes sur le point de dmarrer une restauration directement sur 
 la machine \$In{hostDest}. Les fichiers suivants vont tre restaurs 
@@ -814,7 +832,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Contenu de \${EscHTML(\$dirDisplay)}")}
+\${h2("Contenu de \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -873,7 +891,7 @@ Cette page montre toutes les version disponibles des fichiers sauvegards pour le
      Choisissez le numro de sauvegarde pour voir les attributs de fichiers.
 </ul>
 
-\${h2("Historique de \${EscHTML(\$dirDisplay)}")}
+\${h2("Historique de \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -963,7 +981,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "Seuls les utilisateurs privilgis peuvent arrter ou dmarrer des sauvegardes sur "
                   . " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "Numro invalide \$num";
+$Lang{Invalid_number__num} = "Numro invalide \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "Impossible d\'ouvrir \$file : problme de configuration ?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Seuls les utilisateurs privilgis peuvent voir les fichiers de journal ou les fichiers de configuration.";
 $Lang{Only_privileged_users_can_view_log_files} = "Seuls les utilisateurs privilgis peuvent voir les fichiers de journal.";
@@ -1193,7 +1211,7 @@ $Lang{No} = "non";
 $Lang{Yes} = "oui";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">Le rpertoire \${EscHTML(\$dirDisplay)} est vide
+<tr><td bgcolor="#ffffff">Le rpertoire \$dirDisplay est vide
 </td></tr>
 EOF
 
@@ -1375,11 +1393,11 @@ $Lang{CfgEdit_Title_User_URLs} = "URL des usagers";
 $Lang{CfgEdit_Title_User_Config_Editing} = "Modifications des configurations des usagers";
 $Lang{CfgEdit_Title_Xfer} = "Xfer";
 $Lang{CfgEdit_Title_Xfer_Settings} = "Paramtres des transfers";
+$Lang{CfgEdit_Title_Ftp_Settings} = "Paramtres de FTP";
 $Lang{CfgEdit_Title_Smb_Settings} = "Paramtres de Smb";
 $Lang{CfgEdit_Title_Tar_Settings} = "Paramtres de Tar";
 $Lang{CfgEdit_Title_Rsync_Settings} = "Paramtres de Rsync";
 $Lang{CfgEdit_Title_Rsyncd_Settings} = "Paramtres de Rsyncd";
-$Lang{CfgEdit_Title_BackupPCd_Settings} = "Paramtres de BackupPCd";
 $Lang{CfgEdit_Title_Archive_Settings} = "Paramtres d'archivage";
 $Lang{CfgEdit_Title_Include_Exclude} = "Inclure/Exclure";
 $Lang{CfgEdit_Title_Smb_Paths_Commands} = "Chemins/Commandes Smb";
@@ -1394,7 +1412,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Suspension";
 $Lang{CfgEdit_Title_Other} = "Divers";
 $Lang{CfgEdit_Title_Backup_Settings} = "Paramtres de sauvegarde";
 $Lang{CfgEdit_Title_Client_Lookup} = "Consultation des clients";
-$Lang{CfgEdit_Title_Other} = "Autre";
 $Lang{CfgEdit_Title_User_Commands} = "Commandes des usagers";
 $Lang{CfgEdit_Title_Hosts} = "Machines";
 
