@@ -1,4 +1,4 @@
-#!/bin/perl
+#!/usr/bin/perl
 #
 # Italian i18n file
 #
@@ -46,12 +46,16 @@ $Lang{Admin_Options_Page} = <<EOF;
 </ul>
 -->
 EOF
-$Lang{Unable_to_connect_to_BackupPC_server} = "Impossibile connettersi al server BackupPC",
-            "Questo script CGI (\$MyURL) non &egrave; in grado di connettersi al server"
-          . " BackupPC su \$Conf{ServerHost} alla porta \$Conf{ServerPort}.  L'errore &egrave;:"
-          . " \$err.",
-            "Forse il server BackupPC non &egrave; in esecuzione o c'&egrave; un errore"
-          . " nella configurazione.  Contattare l'amministratore di sistema.";
+
+$Lang{Unable_to_connect_to_BackupPC_server} = "Impossibile connettersi al server BackupPC";
+$Lang{Unable_to_connect_to_BackupPC_server_error_message} = <<EOF;
+Questo script CGI (\$MyURL) non &egrave; in grado di connettersi al server
+BackupPC su \$Conf{ServerHost} alla porta \$Conf{ServerPort}.<br>
+L'errore &egrave;: \$err.<br>
+Forse il server BackupPC non &egrave; in esecuzione o c'&egrave; un errore
+nella configurazione.  Contattare l'amministratore di sistema.
+EOF
+
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
 <form action="\$MyURL" method="get">
@@ -133,7 +137,13 @@ $Lang{BackupPC_Summary} = <<EOF;
 
 \${h1(qq{$Lang{BackupPC__Server_Summary}})}
 <p>
-Questo rapporto di stato &egrave; stato generato il \$now.
+<ul>
+<li>Questo rapporto di stato &egrave; stato generato il \$now.
+<li>Recentemente il sistema dei file di pool &egrave; stato al
+    \$Info{DUlastValue}% (\$DUlastTime).  Il massimo di oggi
+     &egrave; del \$Info{DUDailyMax}% (\$DUmaxTime), mentre quello
+     di ieri era del \$Info{DUDailyMaxPrev}%.
+</ul>
 </p>
 
 \${h2("Host con backup validi")}
@@ -146,7 +156,7 @@ Ci sono \$hostCntGood host sottoposti a backup per un totale di:
      (prima del processo di pooling e compressione).
 </ul>
 </p>
-<table class="tableStnd" border cellpadding="3" cellspacing="1">
+<table class="sortable" id="host_summary_backups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Host </td>
     <td align="center"> Utente </td>
     <td align="center"> Completi </td>
@@ -157,6 +167,7 @@ Ci sono \$hostCntGood host sottoposti a backup per un totale di:
     <td align="center"> Et&agrave; incrementali (giorni) </td>
     <td align="center"> Ultimo Backup (giorni) </td>
     <td align="center"> Stato </td>
+    <td align="center"> Numero errori trasferimento </td>
     <td align="center"> Ultimo tentativo </td></tr>
 \$strGood
 </table>
@@ -165,7 +176,7 @@ Ci sono \$hostCntGood host sottoposti a backup per un totale di:
 <p>
 Ci sono \$hostCntNone host senza alcun backup.
 <p>
-<table class="tableStnd" border cellpadding="3" cellspacing="1">
+<table class="sortable" id="host_summary_nobackups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Host </td>
     <td align="center"> Utente </td>
     <td align="center"> Completi </td>
@@ -176,6 +187,7 @@ Ci sono \$hostCntNone host senza alcun backup.
     <td align="center"> Et&agrave; incrementali (giorni) </td>
     <td align="center"> Ultimo Backup (giorni) </td>
     <td align="center"> Stato </td>
+    <td align="center"> Numero errori trasferimento </td>
     <td align="center"> Ultimo tentativo </td></tr>
 \$strNone
 </table>
@@ -460,7 +472,7 @@ EOF
 
 $Lang{Restore_Options_for__host_Option1} = <<EOF;
 &Egrave; possibile avviare un processo che ripristini questi file direttamente
-su \$host.
+su <b>\$directHost</b>.
 </p><p>
 <b>Attenzione:</b> ogni file esistente che corrisponde ai file selezionati
 sar&agrave; sovrascritto!
@@ -529,8 +541,15 @@ abbastanza spazio sul proprio disco rigido locale per poterlo contenere.
 l\'archivio relativamente a \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (altrimenti l\'archivio conterr&agrave; percorsi completi).
 <br>
-Compressione (0=off, 1=fast,...,9=best)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Compressione (0=off, 1=fast,...,9=best)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Scarica file zip" name="ignore">
 </form>
@@ -825,7 +844,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Contents of \${EscHTML(\$dirDisplay)}")}
+\${h2("Contents of \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -885,7 +904,7 @@ Questa videata mostra tutte le versioni uniche disponibili nei diversi backup:
      attributi del file.
 </ul>
 
-\${h2("Cronologia di \${EscHTML(\$dirDisplay)}")}
+\${h2("Cronologia di \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -975,7 +994,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "Solo gli utenti privilegiati possono arrestare o avviare un backup su"
 		. " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "Numero non valido: \$num";
+$Lang{Invalid_number__num} = "Numero non valido: \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "Impossibile aprire il file \$file: problema di configurazione?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Solo gli utenti privilegiati possono visualizzare i file di log o di configurazione.";
 $Lang{Only_privileged_users_can_view_log_files} = "Solo gli utenti privilegiati possono visualizzare i file di log.";
@@ -1207,7 +1226,7 @@ $Lang{No} = "no";
 $Lang{Yes} = "s&igrave;";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">La directory \${EscHTML(\$dirDisplay)} &egrave; vuota
+<tr><td bgcolor="#ffffff">La directory \$dirDisplay &egrave; vuota
 </td></tr>
 EOF
 
@@ -1388,11 +1407,11 @@ $Lang{CfgEdit_Title_User_URLs} = "URL Utenti";
 $Lang{CfgEdit_Title_User_Config_Editing} = "Modifica Configurazione Utenti";
 $Lang{CfgEdit_Title_Xfer} = "Xfer";
 $Lang{CfgEdit_Title_Xfer_Settings} = "Configurazione Xfer";
+$Lang{CfgEdit_Title_Ftp_Settings} = "Configurazione FTP";
 $Lang{CfgEdit_Title_Smb_Settings} = "Configurazione Smb";
 $Lang{CfgEdit_Title_Tar_Settings} = "Configurazione Tar";
 $Lang{CfgEdit_Title_Rsync_Settings} = "Configurazione Rsync";
 $Lang{CfgEdit_Title_Rsyncd_Settings} = "Configurazione Rsyncd";
-$Lang{CfgEdit_Title_BackupPCd_Settings} = "Configurazione BackupPCd";
 $Lang{CfgEdit_Title_Archive_Settings} = "Configurazione Archivi";
 $Lang{CfgEdit_Title_Include_Exclude} = "Includi/Escludi";
 $Lang{CfgEdit_Title_Smb_Paths_Commands} = "Smb Percorsi/Comandi";
@@ -1407,7 +1426,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Blackouts";
 $Lang{CfgEdit_Title_Other} = "Altro";
 $Lang{CfgEdit_Title_Backup_Settings} = "Configurazione Backup";
 $Lang{CfgEdit_Title_Client_Lookup} = "Client Lookup";
-$Lang{CfgEdit_Title_Other} = "Altro";
 $Lang{CfgEdit_Title_User_Commands} = "Comandi Utente";
 $Lang{CfgEdit_Title_Hosts} = "Hosts";
 
