@@ -1,4 +1,4 @@
-#!/bin/perl
+#!/usr/bin/perl
 
 #my %lang;
 #use strict;
@@ -40,12 +40,16 @@ $Lang{Admin_Options_Page} = <<EOF;
 </ul>
 -->
 EOF
-$Lang{Unable_to_connect_to_BackupPC_server} = "Verbinding met de BackupPC server is mislukt",
-            "Dit CGI script (\$MyURL) kon geen verbinding maken met de BackupPC-server"
-          . " op \$Conf{ServerHost} poort \$Conf{ServerPort}."
-          . " De foutmelding was: \$err.",
-            "Mogelijk draait de BackupPC server niet of is er een "
-          . " configuratiefout.  Gelieve dit te melden aan uw systeembeheerder.";
+
+$Lang{Unable_to_connect_to_BackupPC_server} = "Verbinding met de BackupPC server is mislukt";
+$Lang{Unable_to_connect_to_BackupPC_server_error_message} = <<EOF;
+Dit CGI script (\$MyURL) kon geen verbinding maken met de BackupPC-server
+op \$Conf{ServerHost} poort \$Conf{ServerPort}.<br>
+De foutmelding was: \$err.<br>
+Mogelijk draait de BackupPC server niet of is er een
+configuratiefout.  Gelieve dit te melden aan uw systeembeheerder.
+EOF
+
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
 <form action="\$MyURL" method="get">
@@ -154,6 +158,7 @@ Er zijn \$hostCntGood hosts gebackupt, wat een totaal geeft van:
     <td align="center"> Incr.Lftd (dagen) </td>
     <td align="center"> Vorige Backup (dagen) </td>
     <td align="center"> Status </td>
+    <td align="center"> Aantal fouten </td>
     <td align="center"> Laatste poging</td></tr>
 \$strGood
 </table>
@@ -173,6 +178,7 @@ Er zijn \$hostCntNone hosts zonder backup.
     <td align="center"> Incr.Lftd (dagen) </td>
     <td align="center"> Vorige Backup (dagen) </td>
     <td align="center"> Status </td>
+    <td align="center"> Aantal fouten </td>
     <td align="center"> Laatste poging </td></tr>
 \$strNone
 </table>
@@ -525,8 +531,15 @@ harde schijfruimte beschikken om het bestand te kunnen bevatten.
 aan \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (in het andere geval zal het archiefbestand volledige padnamen bevatten).
 <br>
-Compressie (0=uit, 1=snel,...,9=hoogst)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Compressie (0=uit, 1=snel,...,9=hoogst)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Download Zip-bestand" name="ignore">
 </form>
@@ -821,7 +834,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Inhoud van \${EscHTML(\$dirDisplay)}")}
+\${h2("Inhoud van \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -882,7 +895,7 @@ alle backups heen:
      de attributen van het bestand te bekijken.
 </ul>
 
-\${h2("Geschiedenis van \${EscHTML(\$dirDisplay)}")}
+\${h2("Geschiedenis van \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -971,7 +984,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
 		  "Enkel gebruikers met bijzondere rechten kunnen backups stoppen of starten van machine"
 		. " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "Ongeldig of onjuist nummer \$num";
+$Lang{Invalid_number__num} = "Ongeldig of onjuist nummer \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "Ik kan \$file niet openen: misschien problemen met de configuratie?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Enkel gebruikers met bijzondere rechten kunnen log- of configuratiebestanden bekijken.";
 $Lang{Only_privileged_users_can_view_log_files} = "Enkel gebruikers met bijzondere rechten kunnen logbestanden bekijken.";
@@ -1201,7 +1214,7 @@ $Lang{No} = "nee";
 $Lang{Yes} = "ja";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">De map/directory \${EscHTML(\$dirDisplay)} is leeg
+<tr><td bgcolor="#ffffff">De map/directory \$dirDisplay is leeg
 </td></tr>
 EOF
 
@@ -1392,11 +1405,11 @@ $Lang{CfgEdit_Title_User_URLs} = "Gebruiker URLs";
 $Lang{CfgEdit_Title_User_Config_Editing} = "Wijzigen gebruikersconfiguratie";
 $Lang{CfgEdit_Title_Xfer} = "Overdracht";
 $Lang{CfgEdit_Title_Xfer_Settings} = "Overdracht instellingen";
+$Lang{CfgEdit_Title_Ftp_Settings} = "FTP instellingen";
 $Lang{CfgEdit_Title_Smb_Settings} = "Smb instellingen";
 $Lang{CfgEdit_Title_Tar_Settings} = "Tar instellingen";
 $Lang{CfgEdit_Title_Rsync_Settings} = "Rsync instellingen";
 $Lang{CfgEdit_Title_Rsyncd_Settings} = "Rsyncd instellingen";
-$Lang{CfgEdit_Title_BackupPCd_Settings} = "BackupPCd instellingen";
 $Lang{CfgEdit_Title_Archive_Settings} = "Archivering instellingen";
 $Lang{CfgEdit_Title_Include_Exclude} = "Inclusief/Exclusief";
 $Lang{CfgEdit_Title_Smb_Paths_Commands} = "Smb Pad/Opdrachten";
@@ -1411,7 +1424,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Blackouts";
 $Lang{CfgEdit_Title_Other} = "Andere";
 $Lang{CfgEdit_Title_Backup_Settings} = "Backup instellingen";
 $Lang{CfgEdit_Title_Client_Lookup} = "Cli&euml;nt locatie";
-$Lang{CfgEdit_Title_Other} = "Andere";
 $Lang{CfgEdit_Title_User_Commands} = "Opdrachten van gebruiker";
 $Lang{CfgEdit_Title_Hosts} = "Machines";
 
