@@ -1,7 +1,8 @@
-#!/bin/perl
+#!/usr/bin/perl
 
 #my %lang;
 #use strict;
+use utf8;
 
 # --------------------------------
 
@@ -40,12 +41,16 @@ $Lang{Admin_Options_Page} = <<EOF;
 </ul>
 -->
 EOF
-$Lang{Unable_to_connect_to_BackupPC_server} = "Nie można połączyć się z serwerem BackupPC",
-            "Ten skrypt CGI (\$MyURL) nie może połączyć się z BackupPC"
-          . " serwer na \$Conf{ServerHost} porcie \$Conf{ServerPort}.  Błąd"
-          . " to: \$err.",
-            "Możliwe ,że serwer BackupPC nie jest uruchomiony albo że występuje "
-          . " błąd w konfiguracji.  Proszę powiadomić o tym swojego Administratora.";
+
+$Lang{Unable_to_connect_to_BackupPC_server} = "Nie można połączyć się z serwerem BackupPC";
+$Lang{Unable_to_connect_to_BackupPC_server_error_message} = <<EOF;
+Ten skrypt CGI (\$MyURL) nie może połączyć się z BackupPC
+serwer na \$Conf{ServerHost} porcie \$Conf{ServerPort}.<br>
+Błąd to: \$err.<br>
+Możliwe ,że serwer BackupPC nie jest uruchomiony albo że występuje
+błąd w konfiguracji.  Proszę powiadomić o tym swojego Administratora.
+EOF
+
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
 <form action="\$MyURL" method="get">
@@ -154,6 +159,7 @@ Jest \$hostCntGood hostów które zostaly zabezpieczone, na całkowita liczbę:
     <td align="center"> Wiek Inkr (dni) </td>
     <td align="center"> Ostatnia kopia bezpieczeństwa (dni) </td>
     <td align="center"> Status </td>
+    <td align="center"> #Xfer  błędó</td>
     <td align="center"> Ostatnia próba </td></tr>
 \$strGood
 </table>
@@ -173,6 +179,7 @@ Jest \$hostCntNone hostów bez kopii bezpieczeństwa.
     <td align="center"> Wiek Inkr (dni) </td>
     <td align="center"> Ostatnia kopia bezpieczeństwa (dni) </td>
     <td align="center"> Status </td>
+    <td align="center"> #Xfer  błędó</td>
     <td align="center"> Ostatnia próba </td></tr>
 \$strNone
 </table>
@@ -524,8 +531,15 @@ do przechowania.
 z \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (inaczej bedzie zawierac pełne scieżki do plików).
 <br>
-Kompresja (0=off, 1=fast,...,9=best)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Kompresja (0=off, 1=fast,...,9=best)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Sciągnij plik Zip" name="ignore">
 </form>
@@ -818,7 +832,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Zawartość \${EscHTML(\$dirDisplay)}")}
+\${h2("Zawartość \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -876,7 +890,7 @@ Przedstawienie każdej unikalnej wersji każdego pliku we wszystkich kopiach:
      Wybierz numer kopii aby zobaczyć atrybuty plików.
 </ul>
 
-\${h2("Historia \${EscHTML(\$dirDisplay)}")}
+\${h2("Historia \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -966,7 +980,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "Tylko uprzywilejowani użytkownicy mogą dokonywać kopii na"
 		. " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "Zły numer \$num";
+$Lang{Invalid_number__num} = "Zły numer \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "Niemozna otworzyć \$file: problem z konfiguracja ?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Tylko uprzywilejowani użytkownicy mogą przeglądac logi/pliki konf.";
 $Lang{Only_privileged_users_can_view_log_files} = "Tylko uprzywilejowani użytkownicy mogą przeglądać logi.";
@@ -1196,7 +1210,7 @@ $Lang{No} = "nie";
 $Lang{Yes} = "tak";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">Ten katalog jest \${EscHTML(\$dirDisplay)} pusty
+<tr><td bgcolor="#ffffff">Ten katalog jest \$dirDisplay pusty
 </td></tr>
 EOF
 
@@ -1373,11 +1387,11 @@ $Lang{CfgEdit_Title_User_URLs} = "URLe użytkownika";
 $Lang{CfgEdit_Title_User_Config_Editing} = "Edytowanie konfiguracji użytkownika";
 $Lang{CfgEdit_Title_Xfer} = "Xfer";
 $Lang{CfgEdit_Title_Xfer_Settings} = "Ustawienia Xfer";
+$Lang{CfgEdit_Title_Ftp_Settings} = "Ustawienia FTP";
 $Lang{CfgEdit_Title_Smb_Settings} = "Ustawienia Smb";
 $Lang{CfgEdit_Title_Tar_Settings} = "Ustawienia Tar";
 $Lang{CfgEdit_Title_Rsync_Settings} = "Ustawienia Rsync";
 $Lang{CfgEdit_Title_Rsyncd_Settings} = "Ustawienia Rsyncd";
-$Lang{CfgEdit_Title_BackupPCd_Settings} = "Ustawienia BackupPCd";
 $Lang{CfgEdit_Title_Archive_Settings} = "Ustawienia Archiwizacji";
 $Lang{CfgEdit_Title_Include_Exclude} = "Dodaj/Usuń";
 $Lang{CfgEdit_Title_Smb_Paths_Commands} = "Ściezki/Polecenia Smb";
@@ -1392,7 +1406,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Przeciążenia";
 $Lang{CfgEdit_Title_Other} = "Inne";
 $Lang{CfgEdit_Title_Backup_Settings} = "Ustawienia Kopii";
 $Lang{CfgEdit_Title_Client_Lookup} = "Sprawdzenie klienta";
-$Lang{CfgEdit_Title_Other} = "Inne";
 $Lang{CfgEdit_Title_User_Commands} = "Polecenia dla użytkownika";
 $Lang{CfgEdit_Title_Hosts} = "Hosty";
 
