@@ -1,4 +1,4 @@
-#!/bin/perl
+#!/usr/bin/perl
 #
 # By Reginaldo Ferreira <reginaldo@lepper.com.br> (23.07.2004 for V2.1.10)
 #
@@ -45,12 +45,16 @@ $Lang{Admin_Options_Page} = <<EOF;
 </ul>
 -->
 EOF
-$Lang{Unable_to_connect_to_BackupPC_server} = "Impossvel conectar ao servidor BackupPC",
-            "Este script CGI (\$MyURL) no pode conectar-se ao servidor BackupPC"
-          . " em \$Conf{ServerHost} porta \$Conf{ServerPort}.  O erro"
-          . " foi: \$err.",
-            "Talvez o servidor BackupPC no esteja ativo ou h um "
-          . " erro de configurao. Por favor informe o administrador do sistema.";
+
+$Lang{Unable_to_connect_to_BackupPC_server} = "Impossvel conectar ao servidor BackupPC";
+$Lang{Unable_to_connect_to_BackupPC_server_error_message} = <<EOF;
+Este script CGI (\$MyURL) no pode conectar-se ao servidor BackupPC
+em \$Conf{ServerHost} porta \$Conf{ServerPort}.<br>
+O erro foi: \$err.<br>
+Talvez o servidor BackupPC no esteja ativo ou h um
+erro de configurao. Por favor informe o administrador do sistema.
+EOF
+
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
 <form action="\$MyURL" method="get">
@@ -130,7 +134,12 @@ $Lang{BackupPC_Summary}=<<EOF;
 
 \${h1(qq{$Lang{BackupPC__Server_Summary}})}
 <p>
-Este status foi generado em \$now.
+<ul>
+<li>Este status foi generado em \$now.
+<li>O sistema de arquivos estava recentemente em \$Info{DUlastValue}%
+    (\$DUlastTime), o m?ximo de hoje ? \$Info{DUDailyMax}% (\$DUmaxTime)
+    e o m?ximo de ontem foi \$Info{DUDailyMaxPrev}%.
+</ul>
 </p>
 
 \${h2("Hosts com Backups Completos")}
@@ -143,7 +152,7 @@ Existem \$hostCntGood hosts com backup, de um total de :
      (antes de agrupar e comprimir).
 </ul>
 </p>
-<table class="tableStnd" border cellpadding="3" cellspacing="1">
+<table class="sortable" id="host_summary_backups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Host </td>
     <td align="center"> Usuario </td>
     <td align="center"> #Completo </td>
@@ -154,6 +163,7 @@ Existem \$hostCntGood hosts com backup, de um total de :
     <td align="center"> Incrementais Antig (Dias) </td>
     <td align="center"> ENG Last Backup (days) </td>
     <td align="center"> Estado </td>
+    <td align="center"> N Xfer errs </td>
     <td align="center"> ltima Tentativa </td></tr>
 \$strGood
 </table>
@@ -162,7 +172,7 @@ Existem \$hostCntGood hosts com backup, de um total de :
 <p>
 Existem \$hostCntNone hosts sem backups.
 <p>
-<table class="tableStnd" border cellpadding="3" cellspacing="1">
+<table class="sortable" id="host_summary_nobackups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Host </td>
     <td align="center"> Usuario </td>
     <td align="center"> #Completo </td>
@@ -173,6 +183,7 @@ Existem \$hostCntNone hosts sem backups.
     <td align="center"> Incrementais Antig (Dias) </td>
     <td align="center"> ENG Last Backup (days) </td>
     <td align="center"> Estado </td>
+    <td align="center"> N Xfer errs </td>
     <td align="center"> ltima tentativa </td></tr>
 \$strNone
 </table>
@@ -456,7 +467,7 @@ EOF
 
 $Lang{Restore_Options_for__host_Option1} = <<EOF;
  possvel iniciar um processo que restaurar estes arquivos diretamente em
-\$host.
+<b>\$directHost</b>.
 </p><p>
 <b>Ateno!:</b> Qualquer arquivo existente com o mesmo nome que o que est
 selecionado ser sobrescrito!
@@ -524,8 +535,15 @@ local para armazen-lo.
 a \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (caso contrrio o arquivo conter os caminhos completos).
 <br>
-Compresso (0=desativada, 1=rpida,...,9=mxima)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Compresso (0=desativada, 1=rpida,...,9=mxima)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Download Zip File" name="ignore">
 </form>
@@ -820,7 +838,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Contedo do \${EscHTML(\$dirDisplay)}")}
+\${h2("Contedo do \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -879,7 +897,7 @@ Este quadro mostra cada verso nica disponvel nos diversos backups:
      Selecione o nmero do backup para ver os atributos do arquivo.
 </ul>
 
-\${h2("Histrico de \${EscHTML(\$dirDisplay)}")}
+\${h2("Histrico de \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -969,7 +987,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "Somente os usurios autorizados podem iniciar ou parar as cpias"
 		. " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "Nmero invlido \$num";
+$Lang{Invalid_number__num} = "Nmero invlido \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "No pode abrir \$file: problema de configurao?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Somente os usurios autorizados podem ver registros ou arquivos de configurao.";
 $Lang{Only_privileged_users_can_view_log_files} = "Somente os usurios autorizados podem ver arquivos de registro.";
@@ -1198,7 +1216,7 @@ $Lang{No} = "no";
 $Lang{Yes} = "sim";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">O diretrio \${EscHTML(\$dirDisplay)} est vazio
+<tr><td bgcolor="#ffffff">O diretrio \$dirDisplay est vazio
 </td></tr>
 EOF
 
@@ -1378,11 +1396,11 @@ $Lang{CfgEdit_Title_User_URLs} = "URLs do Usurio";
 $Lang{CfgEdit_Title_User_Config_Editing} = "Edio de Configuraes do Usurio";
 $Lang{CfgEdit_Title_Xfer} = "Transferncia";
 $Lang{CfgEdit_Title_Xfer_Settings} = "Configuraes de transferncia";
+$Lang{CfgEdit_Title_Ftp_Settings} = "Configuraes do FTP";
 $Lang{CfgEdit_Title_Smb_Settings} = "Configuraes do Smb";
-$Lang{CfgEdit_Title_Tar_Settings} = "Configuraes doTar";
+$Lang{CfgEdit_Title_Tar_Settings} = "Configuraes do Tar";
 $Lang{CfgEdit_Title_Rsync_Settings} = "Configuraes do Rsync";
 $Lang{CfgEdit_Title_Rsyncd_Settings} = "Configuraes do Rsyncd";
-$Lang{CfgEdit_Title_BackupPCd_Settings} = "Configuraes do BackupPCd";
 $Lang{CfgEdit_Title_Archive_Settings} = "Configuraes do Archive";
 $Lang{CfgEdit_Title_Include_Exclude} = "Inclui/Exclui";
 $Lang{CfgEdit_Title_Smb_Paths_Commands} = "Caminhos/Comandos do Smb";
@@ -1397,7 +1415,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Blackouts";
 $Lang{CfgEdit_Title_Other} = "Outros";
 $Lang{CfgEdit_Title_Backup_Settings} = "Configuraes do Backup";
 $Lang{CfgEdit_Title_Client_Lookup} = "Busca Cliente";
-$Lang{CfgEdit_Title_Other} = "Outro";
 $Lang{CfgEdit_Title_User_Commands} = "Commandos de usurio";
 $Lang{CfgEdit_Title_Hosts} = "Hosts";
 
