@@ -1,4 +1,4 @@
-#!/bin/perl
+#!/usr/bin/perl
 
 #my %lang;
 #use strict;
@@ -41,9 +41,14 @@ $Lang{Admin_Options_Page} = <<EOF;
 </ul>
 -->
 EOF
-$Lang{Unable_to_connect_to_BackupPC_server} = "无法连接到 BackupPC 服务器",
-            "CGI 脚本程序 (\$MyURL) 无法连接到 BackupPC 服务器 \$Conf{ServerHost} 端口 \$Conf{ServerPort}。错误信息：\$err。",
-            "可能 BackupPC 服务器没有运行，或者服务器配置不正确。请通知网络系统管理员。";
+
+$Lang{Unable_to_connect_to_BackupPC_server} = "无法连接到 BackupPC 服务器";
+$Lang{Unable_to_connect_to_BackupPC_server_error_message} = <<EOF;
+CGI 脚本程序 (\$MyURL) 无法连接到 BackupPC 服务器 \$Conf{ServerHost} 端口 \$Conf{ServerPort}。错误信息：\$err。
+可能 BackupPC 服务器没有运行，或者服务器配置不正确。请通知网络系统管理员。
+<br><br>
+EOF
+
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
 <form action="\$MyURL" method="get">
@@ -152,6 +157,7 @@ $Lang{BackupPC_Summary} = <<EOF;
     <td align="center"> 最后一次增量备份 (天前) </td>
     <td align="center"> 最后一次备份 (天前) </td>
     <td align="center"> 当前状态 </td>
+    <td align="center"> 传输错误数目 </td>
     <td align="center"> 最后一次备份结果 </td></tr>
 \$strGood
 </table>
@@ -171,6 +177,7 @@ $Lang{BackupPC_Summary} = <<EOF;
     <td align="center"> 最后一次增量备份 (天前) </td>
     <td align="center"> 最后一次备份 (天前) </td>
     <td align="center"> 当前状态 </td>
+    <td align="center"> 传输错误数目 </td>
     <td align="center"> 最后一次备份结果 </td></tr>
 \$strNone
 </table>
@@ -515,8 +522,15 @@ $Lang{Option_2__Download_Zip_archive} = <<EOF;
 <input type="checkbox" value="1" name="relative" checked> 备档中所有文件具有相对路径，在 \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)} 目录内
 （否则备档中文件具有完整路径）。
 <br>
-选择压缩比（0＝不压缩，1＝最低但速度快，...，9＝最高但速度慢）
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>选择压缩比（0＝不压缩，1＝最低但速度快，...，9＝最高但速度慢）</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="下载 Zip 文件" name="ignore">
 </form>
@@ -803,7 +817,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("\${EscHTML(\$dirDisplay)} 的内容")}
+\${h2("\$dirDisplay 的内容")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -858,7 +872,7 @@ $Lang{DirHistory_for__host} = <<EOF;
 <li> 具有相同版本号的文件可能在不同备份中有不同的文件属性。可以点击备份序列号来查看文件在相应备份中的属性。
 </ul>
 
-\${h2("\${EscHTML(\$dirDisplay)} 的历史")}
+\${h2("\$dirDisplay 的历史")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -948,7 +962,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "只有特权用户可以执行备份的开始或停止操作于客户机"
 		. " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "无效数字 \$num";
+$Lang{Invalid_number__num} = "无效数字 \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "无法打开文件 \$file：配置有误？";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "只有特权用户可以查看日志或配置文件。";
 $Lang{Only_privileged_users_can_view_log_files} = "只有特权用户可以查看日志文件。";
@@ -1172,7 +1186,7 @@ $Lang{No} = "否";
 $Lang{Yes} = "是";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">目录 \${EscHTML(\$dirDisplay)} 是空目录
+<tr><td bgcolor="#ffffff">目录 \$dirDisplay 是空目录
 </td></tr>
 EOF
 
@@ -1347,11 +1361,11 @@ $Lang{CfgEdit_Title_User_URLs} = "用户 URLs";
 $Lang{CfgEdit_Title_User_Config_Editing} = "用户配置编辑";
 $Lang{CfgEdit_Title_Xfer} = "传输";
 $Lang{CfgEdit_Title_Xfer_Settings} = "传输设置";
+$Lang{CfgEdit_Title_Ftp_Settings} = "FTP 设置";
 $Lang{CfgEdit_Title_Smb_Settings} = "Smb 设置";
 $Lang{CfgEdit_Title_Tar_Settings} = "Tar 设置";
 $Lang{CfgEdit_Title_Rsync_Settings} = "Rsync 设置";
 $Lang{CfgEdit_Title_Rsyncd_Settings} = "Rsyncd 设置";
-$Lang{CfgEdit_Title_BackupPCd_Settings} = "BackupPCd 设置";
 $Lang{CfgEdit_Title_Archive_Settings} = "备档设置";
 $Lang{CfgEdit_Title_Include_Exclude} = "包含／排除";
 $Lang{CfgEdit_Title_Smb_Paths_Commands} = "Smb 路径／命令";
@@ -1366,7 +1380,6 @@ $Lang{CfgEdit_Title_Blackouts} = "备份暂停期";
 $Lang{CfgEdit_Title_Other} = "其它";
 $Lang{CfgEdit_Title_Backup_Settings} = "备份设置";
 $Lang{CfgEdit_Title_Client_Lookup} = "客户机查找";
-$Lang{CfgEdit_Title_Other} = "其它";
 $Lang{CfgEdit_Title_User_Commands} = "用户命令";
 $Lang{CfgEdit_Title_Hosts} = "客户机";
 
