@@ -11,7 +11,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2009  Craig Barratt
+#   Copyright (C) 2001-2013  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #
 #========================================================================
 #
-# Version 3.2.0, released 31 Jul 2010.
+# Version 3.3.0, released 14 Apr 2013.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -71,8 +71,8 @@ sub start
 	$bpc->backupFileConfFix($conf, "TarShareName");
 
         if ( defined($conf->{BackupFilesExclude}{$t->{shareName}}) ) {
-            foreach my $file ( @{$conf->{BackupFilesExclude}{$t->{shareName}}} )
-            {
+            foreach my $file2 ( @{$conf->{BackupFilesExclude}{$t->{shareName}}} ) {
+                my $file = $file2;
                 $file = "./$2" if ( $file =~ m{^(\./+|/+)(.*)}s );
                 $file = encode($conf->{ClientCharset}, $file)
                             if ( $conf->{ClientCharset} ne "" );
@@ -80,7 +80,8 @@ sub start
             }
         }
         if ( defined($conf->{BackupFilesOnly}{$t->{shareName}}) ) {
-            foreach my $file ( @{$conf->{BackupFilesOnly}{$t->{shareName}}} ) {
+            foreach my $file2 ( @{$conf->{BackupFilesOnly}{$t->{shareName}}} ) {
+                my $file = $file2;
                 $file = $2 if ( $file =~ m{^(\./+|/+)(.*)}s );
 		$file = "./$file";
                 $file = encode($conf->{ClientCharset}, $file)
